@@ -1,14 +1,14 @@
 package Datahub::Factory::Importer::KMSKA;
 
-use Datahub::Factory::Sane;
-
-our $VERSION = '0.100';
+use strict;
+use warnings;
 
 use Moo;
 use Catmandu;
+
 use Config::Simple;
-use Datahub::Factory::Importer::KMSKA::TMS::Index;
-use namespace::clean;
+
+use Datahub::Factory::Importer::TMS::Index;
 
 with 'Datahub::Factory::Importer';
 
@@ -16,19 +16,23 @@ has db_host     => (is => 'ro', required => 1);
 has db_name     => (is => 'ro', required => 1);
 has db_user     => (is => 'ro', required => 1);
 has db_password => (is => 'ro', required => 1);
-has generate_temp_tables => (is => 'ro', default => 1);
+
+has tms      => (is => 'lazy');
 
 sub _build_importer {
     my $self = shift;
     my $dsn = sprintf('dbi:mysql:%s', $self->db_name);
-
-    my $query = 'select * from CITvgsrpObjTombstoneD_RO;';
+    # Add indices
+    $self->logger->info('Creating indices on TMS tables.');
+    Datahub::Factory::Importer::TMS::Index->new(
+        db_host => $self->db_host,
+        db_name => $self->db_name,
+        db_user => $self->db_user,
+        db_password => $self->db_password
+    );
+    my $query = 'select * from vgsrpObjTombstoneD_RO;';
     my $importer = Catmandu->importer('DBI', dsn => $dsn, host => $self->db_host, user => $self->db_user, password => $self->db_password, query => $query, encoding => ':iso-8859-1');
-
-    if ($self->generate_temp_tables) {
-        $self->prepare();
-    }
-
+    $self->prepare();
     return $importer
 }
 
@@ -43,14 +47,8 @@ sub prepare {
     $self->__dimensions();
     $self->logger->info('Adding "subjects" temporary table.');
     $self->__subjects();
-    $self->logger->info('Adding "constituents" temporary table.');
-    $self->__constituents();
-    $self->logger->info('Adding "datapids" temporary table.');
-    $self->__datapids();
-    $self->logger->info('Adding "representationpids" temporary table.');
-    $self->__representationpids();
-    $self->logger->info('Adding "workpids" temporary table.');
-    $self->__workpids();
+    $self->logger->info('Adding "pids" temporary table.');
+    $self->__pids();
 }
 
 sub prepare_call {
@@ -109,48 +107,55 @@ sub merge_call {
     }
 }
 
-sub __constituents {
-    my $self = shift;
-    $self->prepare_call('SELECT * FROM vconstituents', 'constituents');
-}
-
 sub __classifications {
     my $self = shift;
-    $self->prepare_call('SELECT * FROM vclassifications', 'classifications');
+    $self->prepare_call('select ClassificationID as _id, Classification as term from Classifications', 'classifications');
 }
 
 sub __period {
     my $self = shift;
-    $self->prepare_call('SELECT * FROM vperiods', 'periods');
+    $self->prepare_call('select ObjectID as _id, Period as term from ObjContext', 'periods');
 }
 
-sub __datapids {
+sub __pids {
     my $self = shift;
-    $self->prepare_call('SELECT * FROM vdatapids', 'datapids');
-}
-
-sub __workpids {
-    my $self = shift;
-    $self->prepare_call('SELECT * FROM vworkpids', 'workpids');
-}
-
-sub __representationpids {
-    my $self = shift;
-    $self->prepare_call('SELECT * FROM vperiods', 'representationpids');
+    # key is object_number
+    $self->prepare_call('select ObjectNumber as _id, workPidURI as workPid, dataPidURI as dataPid from Cit_KMSKApids_conversie_gecorrigeerd', 'Cit_KMSKApids_conversie_gecorrigeerd');
 }
 
 sub __dimensions {
     my $self = shift;
-    $self->merge_call('SELECT * FROM vdimensions', 'dimensions', 'dimensions');
+    my $query = "SELECT o.ObjectID as objectid, d.Dimension as dimension, t.DimensionType as type, e.Element as element, u.UnitName as unit
+    FROM vgsrpObjTombstoneD_RO o
+    LEFT JOIN
+        DimItemElemXrefs x ON x.ID = o.ObjectID
+    INNER JOIN
+        Dimensions d ON d.DimItemElemXrefID = x.DimItemElemXrefID
+    INNER JOIN
+        DimensionUnits u ON u.UnitID = d.PrimaryUnitID
+    INNER JOIN
+        DimensionTypes t ON t.DimensionTypeID = d.DimensionTypeID
+    INNER JOIN
+        DimensionElements e ON e.ElementID = x.ElementID
+    WHERE
+        x.TableID = '108'
+    AND 
+        x.ElementID = '3';";
+    $self->merge_call($query, 'dimensions', 'dimensions');
 }
 
 sub __subjects {
     my $self = shift;
-    $self->merge_call('SELECT * FROM vsubjects', 'subjects', 'subjects');
+    my $query = "SELECT o.ObjectID as objectid, t.Term as subject
+    FROM Terms t, vgsrpObjTombstoneD_RO o, ThesXrefs x, ThesXrefTypes y
+    WHERE
+    x.TermID = t.TermID and
+    x.ID = o.ObjectID and
+    x.ThesXrefTypeID = y.ThesXrefTypeID and
+    y.ThesXrefTypeID = 30;"; # Only those from the VKC website
+    $self->merge_call($query, 'subjects', 'subjects');
 }
-
 1;
-
 __END__
 
 =encoding utf-8
@@ -236,4 +241,4 @@ L<Datahub::Factory>
 L<Datahub::Factory::Importer::TMS>
 L<Catmandu>
 
-=cut
+=cut
\ No newline at end of file
