@@ -1,12 +1,12 @@
 package Datahub::Factory::Importer::VKC;
 
-use Datahub::Factory::Sane;
+use strict;
+use warnings;
 
-our $VERSION = '0.100';
+our $VERSION = '0.8';
 
 use Moo;
 use Catmandu;
-use namespace::clean;
 
 with 'Datahub::Factory::Importer';
 
@@ -78,4 +78,4 @@ L<Datahub::Factory>
 L<Datahub::Factory::CollectiveAccess>
 L<Catmandu>
 
-=cut
+=cut
\ No newline at end of file
